@@ -85,6 +85,11 @@ PathBar::PathBar(QWidget* parent):
     // ensure the parent's background is shown behind the bar
     scrollArea_->viewport()->setAutoFillBackground(false);
     buttonsWidget_->setAutoFillBackground(false);
+
+    // for wheel scrolling over buttons (= visible widgets)
+    buttonsWidget_->installEventFilter (this);
+    scrollToStart_->installEventFilter (this);
+    scrollToEnd_->installEventFilter (this);
 }
 
 void PathBar::resizeEvent(QResizeEvent* event) {
@@ -95,30 +100,13 @@ void PathBar::resizeEvent(QResizeEvent* event) {
     }
 }
 
-void PathBar::wheelEvent(QWheelEvent* event) {
-    QWidget::wheelEvent(event);
-    QAbstractSlider::SliderAction action = QAbstractSlider::SliderNoAction;
-    int vDelta = event->angleDelta().y();
-    if(vDelta > 0) {
-        if(scrollToStart_->isEnabled()) {
-            action = QAbstractSlider::SliderSingleStepSub;
-        }
-    }
-    else if(vDelta < 0) {
-        if(scrollToEnd_->isEnabled()) {
-            action = QAbstractSlider::SliderSingleStepAdd;
-        }
-    }
-    scrollArea_->horizontalScrollBar()->triggerAction(action);
-}
-
 void PathBar::mousePressEvent(QMouseEvent* event) {
     QWidget::mousePressEvent(event);
     if(event->button() == Qt::LeftButton) {
         openEditor();
     }
     else if(event->button() == Qt::MiddleButton) {
-        PathButton* btn = qobject_cast<PathButton*>(childAt(event->x(), event->y()));
+        PathButton* btn = qobject_cast<PathButton*>(childAt(event->position().toPoint()));
         if(btn != nullptr) {
             scrollArea_->ensureWidgetVisible(btn,
                                              1); // a harmless compensation for a miscalculation in Qt
@@ -140,6 +128,28 @@ void PathBar::contextMenuEvent(QContextMenuEvent* event) {
     menu->popup(mapToGlobal(event->pos()));
 }
 
+bool PathBar::eventFilter(QObject* watched, QEvent* event) {
+    if(event->type() == QEvent::Wheel
+       && (watched == buttonsWidget_ || watched == scrollToStart_ || watched == scrollToEnd_)) {
+        QWheelEvent* we = static_cast<QWheelEvent*>(event);
+        QAbstractSlider::SliderAction action = QAbstractSlider::SliderNoAction;
+        int vDelta = we->angleDelta().y();
+        if(vDelta > 0) {
+            if(scrollToStart_->isEnabled()) {
+                action = QAbstractSlider::SliderSingleStepSub;
+            }
+        }
+        else if(vDelta < 0) {
+            if(scrollToEnd_->isEnabled()) {
+                action = QAbstractSlider::SliderSingleStepAdd;
+            }
+        }
+        scrollArea_->horizontalScrollBar()->triggerAction(action);
+        return true;
+    }
+    return QWidget::eventFilter(watched, event);
+}
+
 void PathBar::updateScrollButtonVisibility() {
     // Wait for the horizontal scrollbar to be completely shaped.
     // Without this, the enabled state of arrow buttons might be
@@ -332,6 +342,15 @@ void PathBar::closeEditor() {
     if(tempPathEdit_ == nullptr) {
         return;
     }
+
+    // WARNING: The d-tor of QWidget deletes its layout and sets it to null while the widget is
+    // still valid and before its children are destroyed. On the other hand, if the pathbar is
+    // deleted while the path-edit has focus, before it is destroyed, the path-edit will lose
+    // focus and call the current function. Therefore, the following nullity check is necessary.
+    if(layout() == nullptr) {
+        return;
+    }
+
     // If a menu has popped up synchronously (with QMenu::exec), the path buttons may be drawn
     // but the path-edit may not disappear until the menu is closed. So, we hide it here.
     // However, since hiding the path-edit makes it lose focus and emit editingFinished(),
