@@ -16,12 +16,12 @@
     <message>
         <location filename="../app-chooser-dialog.ui" line="46"/>
         <source>Custom Command</source>
-        <translation>Orden personalizada</translation>
+        <translation>Comando personalizado</translation>
     </message>
     <message>
         <location filename="../app-chooser-dialog.ui" line="52"/>
         <source>Command line to execute:</source>
-        <translation>Línea de órdenes que ejecutar:</translation>
+        <translation>Línea de comandos para ejecutar:</translation>
     </message>
     <message>
         <location filename="../app-chooser-dialog.ui" line="62"/>
@@ -48,7 +48,7 @@
     <message>
         <location filename="../app-chooser-dialog.ui" line="91"/>
         <source>Keep terminal window open after command execution</source>
-        <translation>Mantener la terminal abierta tras la ejecución de la orden</translation>
+        <translation>Mantener la ventana de la terminal abierta tras la ejecución del comando</translation>
     </message>
     <message>
         <location filename="../app-chooser-dialog.ui" line="98"/>
@@ -91,7 +91,7 @@
     <message>
         <location filename="../edit-bookmarks.ui" line="102"/>
         <source>Use drag and drop to reorder the items</source>
-        <translation>Arrastre y suelte para reordenar los elementos</translation>
+        <translation>Use Arrastrar y soltar para reordenar los elementos</translation>
     </message>
 </context>
 <context>
@@ -114,7 +114,7 @@
     <message>
         <location filename="../exec-file.ui" line="62"/>
         <source>Execute in &amp;Terminal</source>
-        <translation>Ejecutar en una &amp;terminal</translation>
+        <translation>Ejecutar en una &amp;Terminal</translation>
     </message>
     <message>
         <location filename="../exec-file.ui" line="85"/>
@@ -132,7 +132,7 @@
     <message>
         <location filename="../filedialog.ui" line="22"/>
         <source>Path:</source>
-        <translation>Ruta:</translation>
+        <translation>Ubicación:</translation>
     </message>
     <message>
         <location filename="../filedialog.ui" line="65"/>
@@ -238,7 +238,7 @@
     <message>
         <location filename="../file-props.ui" line="287"/>
         <source>Created:</source>
-        <translation>Creación:</translation>
+        <translation>Creado:</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="310"/>
@@ -253,12 +253,12 @@
     <message>
         <location filename="../file-props.ui" line="342"/>
         <source>Choose emblem</source>
-        <translation>Elegir un emblema</translation>
+        <translation>Elige emblema</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="361"/>
         <source>Clear emblem</source>
-        <translation>Borrar el emblema</translation>
+        <translation>Borrar emblema</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="414"/>
@@ -334,7 +334,7 @@
     <message>
         <location filename="../file-props.ui" line="749"/>
         <source>SetUID</source>
-        <translation>Asignar UID</translation>
+        <translation>Definir UID</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="756"/>
@@ -558,7 +558,7 @@ What do you want to do with it?</source>
     <message>
         <location filename="../filedialog.cpp" line="206"/>
         <source>Show Hidden</source>
-        <translation>Mostrar elementos ocultos</translation>
+        <translation>Mostrar ocultos</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="218"/>
@@ -673,8 +673,8 @@ Do you want to replace it?</source>
         <location filename="../filemenu.cpp" line="357"/>
         <source>Do you want to open these %1 files?</source>
         <translation>
-            <numerusform>¿Quiere abrir este archivo?</numerusform>
-            <numerusform>¿Quiere abrir estos %1 archivos?</numerusform>
+            <numerusform>¿Quiere abrir el archivo %1?</numerusform>
+            <numerusform>¿Quiere abrir los archivos %1?</numerusform>
         </translation>
     </message>
     <message>
@@ -938,7 +938,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../filepropsdialog.cpp" line="405"/>
         <source>%p% used</source>
-        <translation>%p&#xa0;% usado</translation>
+        <translation>%p % usado</translation>
     </message>
     <message>
         <location filename="../filepropsdialog.cpp" line="406"/>
@@ -989,17 +989,17 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>You should add at least one directory to search.</source>
         <translation>Debe añadir al menos un directorio donde buscar.</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="159"/>
+        <location filename="../filesearchdialog.cpp" line="164"/>
         <source>Select a folder</source>
         <translation>Seleccione una carpeta</translation>
     </message>
@@ -1022,12 +1022,12 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="57"/>
         <source>Empty Trash</source>
-        <translation>Vaciar la papelera</translation>
+        <translation>Vaciar Papelera</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="69"/>
         <source>Create &amp;New</source>
-        <translation>Crear &amp;nuevo</translation>
+        <translation>Crear &amp;Nuevo</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="74"/>
@@ -1047,7 +1047,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="98"/>
         <source>Sorting</source>
-        <translation>Ordenar</translation>
+        <translation>Ordenando</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="103"/>
@@ -1082,7 +1082,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="208"/>
         <source>By Deletion Time</source>
-        <translation>Por momento de eliminación</translation>
+        <translation>Por tiempo de eliminación</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="211"/>
@@ -1165,7 +1165,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermodel.cpp" line="324"/>
         <source>Created:</source>
-        <translation>Creación:</translation>
+        <translation>Creado:</translation>
     </message>
     <message>
         <location filename="../foldermodel.cpp" line="329"/>
@@ -1247,7 +1247,7 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::MountOperationPasswordDialog</name>
     <message>
-        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
+        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
         <source>&amp;Connect</source>
         <translation>&amp;Conectar</translation>
     </message>
@@ -1406,7 +1406,7 @@ Modificación: %2</translation>
     <message>
         <location filename="../renamedialog.cpp" line="108"/>
         <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&lt;b&gt;El archivo no puede sobrescribirse a sí mismo.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Seleccione otro nombre.&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;El archivo no puede sobreescribirse a si mismo.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Por favor seleccione otro nombre.&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -1469,11 +1469,16 @@ Modificación: %2</translation>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
+        <source>Session length is determined by password manager</source>
+        <translation>La duración de la sesión la determina el administrador de contraseñas</translation>
+    </message>
+    <message>
+        <location filename="../mount-operation-password.ui" line="140"/>
         <source>Remember password for &amp;this session</source>
         <translation>Recordar contraseña para &amp;esta sesión</translation>
     </message>
     <message>
-        <location filename="../mount-operation-password.ui" line="147"/>
+        <location filename="../mount-operation-password.ui" line="150"/>
         <source>Remember &amp;forever</source>
         <translation>Recordar &amp;para siempre</translation>
     </message>
@@ -1484,60 +1489,60 @@ Modificación: %2</translation>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="669"/>
         <location filename="../mountoperation.cpp" line="297"/>
-        <location filename="../utilities.cpp" line="150"/>
-        <location filename="../utilities.cpp" line="289"/>
+        <location filename="../utilities.cpp" line="154"/>
+        <location filename="../utilities.cpp" line="317"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="166"/>
+        <location filename="../utilities.cpp" line="170"/>
         <source>Rename File</source>
-        <translation>Cambiar nombre de archivo</translation>
+        <translation>Renombrar archivo</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="167"/>
+        <location filename="../utilities.cpp" line="171"/>
         <source>Please enter a new name:</source>
-        <translation>Introduzca un nombre nuevo:</translation>
+        <translation>Por favor, introduzca un nombre nuevo:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="226"/>
+        <location filename="../utilities.cpp" line="230"/>
         <source>Create Folder</source>
         <translation>Crear carpeta</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="231"/>
+        <location filename="../utilities.cpp" line="235"/>
         <source>Please enter a new file name:</source>
-        <translation>Introduzca un nombre de archivo nuevo:</translation>
-    </message>
-    <message>
-        <location filename="../utilities.cpp" line="232"/>
-        <source>New file</source>
-        <translation type="unfinished"></translation>
+        <translation>Por favor, introduzca un nombre de archivo nuevo:</translation>
     </message>
     <message>
         <location filename="../utilities.cpp" line="236"/>
+        <source>New file</source>
+        <translation>Nuevo archivo</translation>
+    </message>
+    <message>
+        <location filename="../utilities.cpp" line="240"/>
         <source>Please enter a new folder name:</source>
         <translation>Introduzca el nombre nuevo de la carpeta:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="237"/>
+        <location filename="../utilities.cpp" line="241"/>
         <source>New folder</source>
-        <translation>Carpeta nueva</translation>
+        <translation>Nueva carpeta</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="242"/>
+        <location filename="../utilities.cpp" line="246"/>
         <source>Enter a name for the new %1:</source>
         <translation>Introduzca un nombre para el nuevo %1:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="227"/>
+        <location filename="../utilities.cpp" line="231"/>
         <source>Create File</source>
         <translation>Crear archivo</translation>
     </message>
     <message>
         <location filename="../filepropsdialog.cpp" line="687"/>
         <source>Custom Icon Error</source>
-        <translation>Icono de error personalizado</translation>
+        <translation>Error de icono personalizado</translation>
     </message>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="41"/>
@@ -1552,7 +1557,7 @@ Modificación: %2</translation>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="355"/>
         <source>No default application is set to launch &apos;%1&apos;</source>
-        <translation>No hay ninguna aplicación predeterminada configurada para iniciar «%1»</translation>
+        <translation>No hay aplicación predeterminada para iniciar &apos;%1&apos;</translation>
     </message>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="396"/>
