@@ -132,7 +132,7 @@
     <message>
         <location filename="../filedialog.ui" line="22"/>
         <source>Path:</source>
-        <translation type="unfinished"></translation>
+        <translation>Camiño:</translation>
     </message>
     <message>
         <location filename="../filedialog.ui" line="65"/>
@@ -538,17 +538,17 @@ Que quere facer con el?</translation>
     <message>
         <location filename="../filedialog.cpp" line="174"/>
         <source>Icon Sizes</source>
-        <translation type="unfinished"></translation>
+        <translation>Tamaños das iconas</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="176"/>
         <source>Size of big icons:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tamaño das iconas grandes:</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="183"/>
         <source>Size of small icons:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tamaño das iconas pequenas:</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="190"/>
@@ -558,27 +558,27 @@ Que quere facer con el?</translation>
     <message>
         <location filename="../filedialog.cpp" line="206"/>
         <source>Show Hidden</source>
-        <translation type="unfinished">Amosar agochados</translation>
+        <translation>Mostrar oculto</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="218"/>
         <source>Show Thumbnails</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar miniaturas</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="223"/>
         <source>Show File Tooltips</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar consellos sobre ficheiros</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="230"/>
         <source>Smooth Scrolling</source>
-        <translation type="unfinished"></translation>
+        <translation>Desprazamento suave</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="245"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Opcións</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="595"/>
@@ -649,7 +649,7 @@ Quere sobrescribilo?</translation>
     <message>
         <location filename="../filedialog_p.h" line="40"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation> px</translation>
     </message>
 </context>
 <context>
@@ -662,14 +662,14 @@ Quere sobrescribilo?</translation>
     <message>
         <location filename="../filemenu.cpp" line="356"/>
         <source>Many files</source>
-        <translation type="unfinished"></translation>
+        <translation>Moitos arquivos</translation>
     </message>
     <message numerus="yes">
         <location filename="../filemenu.cpp" line="357"/>
         <source>Do you want to open these %1 files?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Quere abrir este ficheiro % 1?</numerusform>
+            <numerusform>Quere abrir estes ficheiros % 1?</numerusform>
         </translation>
     </message>
     <message>
@@ -696,17 +696,17 @@ Quere sobrescribilo?</translation>
     <message>
         <location filename="../filemenu.cpp" line="226"/>
         <source>Mount</source>
-        <translation type="unfinished">Montar</translation>
+        <translation>Montar</translation>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="240"/>
         <source>Unmount</source>
-        <translation type="unfinished">Desmontar</translation>
+        <translation>Desmontar</translation>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="254"/>
         <source>Eject</source>
-        <translation type="unfinished">Expulsar</translation>
+        <translation>Expulsar</translation>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="313"/>
@@ -798,17 +798,17 @@ Desexa eliminalos no seu canto?</translation>
     <message numerus="yes">
         <location filename="../fileoperation.cpp" line="405"/>
         <source>Do you want to delete the selected file(s)?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Queres eliminar o ficheiro seleccionado?</numerusform>
+            <numerusform>Queres eliminar os ficheiros seleccionados?</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../fileoperation.cpp" line="423"/>
         <source>Do you want to move the selected file(s) to trash can?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Queres mover o ficheiro seleccionado á papeleira?</numerusform>
+            <numerusform>Queres mover os ficheiros seleccionados á papeleira?</numerusform>
         </translation>
     </message>
 </context>
@@ -928,7 +928,7 @@ Desexa eliminalos no seu canto?</translation>
         <location filename="../filepropsdialog.cpp" line="317"/>
         <location filename="../filepropsdialog.cpp" line="324"/>
         <source>N/A</source>
-        <translation type="unfinished"></translation>
+        <translation>N/A</translation>
     </message>
     <message>
         <location filename="../filepropsdialog.cpp" line="328"/>
@@ -1022,7 +1022,7 @@ Desexa eliminalos no seu canto?</translation>
     <message>
         <location filename="../foldermenu.cpp" line="57"/>
         <source>Empty Trash</source>
-        <translation type="unfinished">Baleirar o lixo</translation>
+        <translation>Baleirar o lixo</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="69"/>
@@ -1077,7 +1077,7 @@ Desexa eliminalos no seu canto?</translation>
     <message>
         <location filename="../foldermenu.cpp" line="205"/>
         <source>By Creation Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Por Tempo de Creación</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="208"/>
@@ -1122,7 +1122,7 @@ Desexa eliminalos no seu canto?</translation>
     <message>
         <location filename="../foldermenu.cpp" line="250"/>
         <source>Hidden Last</source>
-        <translation type="unfinished"></translation>
+        <translation>Último oculto</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="258"/>
@@ -1160,12 +1160,12 @@ Desexa eliminalos no seu canto?</translation>
     <message>
         <location filename="../foldermodel.cpp" line="322"/>
         <source>N/A</source>
-        <translation type="unfinished"></translation>
+        <translation>N/A</translation>
     </message>
     <message>
         <location filename="../foldermodel.cpp" line="324"/>
         <source>Created:</source>
-        <translation type="unfinished"></translation>
+        <translation>Creada:</translation>
     </message>
     <message>
         <location filename="../foldermodel.cpp" line="329"/>
@@ -1200,7 +1200,7 @@ Desexa eliminalos no seu canto?</translation>
     <message>
         <location filename="../foldermodel.cpp" line="409"/>
         <source>Created</source>
-        <translation type="unfinished"></translation>
+        <translation>Creada</translation>
     </message>
     <message>
         <location filename="../foldermodel.cpp" line="412"/>
@@ -1406,7 +1406,7 @@ Modificado: %2</translation>
     <message>
         <location filename="../renamedialog.cpp" line="108"/>
         <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;&lt;b&gt;O ficheiro non pode sobrescribirse por si mesmo.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Seleccione outro nome.&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -1414,7 +1414,7 @@ Modificado: %2</translation>
     <message>
         <location filename="../sidepane.cpp" line="45"/>
         <source>Lists</source>
-        <translation type="unfinished"></translation>
+        <translation>Listas</translation>
     </message>
     <message>
         <location filename="../sidepane.cpp" line="46"/>
@@ -1470,7 +1470,7 @@ Modificado: %2</translation>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
         <source>Session length is determined by password manager</source>
-        <translation type="unfinished"></translation>
+        <translation>A duración da sesión está determinada polo xestor de contrasinais</translation>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="140"/>
@@ -1517,7 +1517,7 @@ Modificado: %2</translation>
     <message>
         <location filename="../utilities.cpp" line="236"/>
         <source>New file</source>
-        <translation type="unfinished"></translation>
+        <translation>Novo ficheiro</translation>
     </message>
     <message>
         <location filename="../utilities.cpp" line="240"/>
@@ -1573,7 +1573,7 @@ Modificado: %2</translation>
         <location filename="../foldermodelitem.cpp" line="61"/>
         <location filename="../foldermodelitem.cpp" line="74"/>
         <source>N/A</source>
-        <translation type="unfinished"></translation>
+        <translation>N/A</translation>
     </message>
 </context>
 <context>
@@ -1753,7 +1753,7 @@ Modificado: %2</translation>
     <message>
         <location filename="../filesearch.ui" line="51"/>
         <source>Case sensitive</source>
-        <translation type="unfinished"></translation>
+        <translation>Sensible a maiúsculas e minúsculas</translation>
     </message>
     <message>
         <location filename="../filesearch.ui" line="125"/>
