@@ -360,7 +360,7 @@
     <message>
         <location filename="../appchooserdialog.cpp" line="268"/>
         <source>Select an application to open &quot;%1&quot; files</source>
-        <translation>Pasirinkite programą, kad atvertumėte failus &quot;%1&quot;</translation>
+        <translation>Pasirinkite programą, kad atvertumėte „%1“ failus</translation>
     </message>
 </context>
 <context>
@@ -381,7 +381,7 @@
     <message>
         <location filename="../core/dirlistjob.cpp" line="48"/>
         <source>The specified directory &apos;%1&apos; is not valid</source>
-        <translation>Nurodytas katalogas &quot;%1&quot; yra neteisingas</translation>
+        <translation>Nurodytas katalogas „%1“ yra neteisingas</translation>
     </message>
 </context>
 <context>
@@ -459,20 +459,20 @@
         <location filename="../execfiledialog.cpp" line="40"/>
         <source>This file &apos;%1&apos; seems to be a desktop entry.
 What do you want to do with it?</source>
-        <translation>Atrodo, kad šis failas &quot;%1&quot; yra darbalaukio įrašas.
+        <translation>Atrodo, kad šis failas „%1“ yra darbalaukio įrašas.
 Ką norėtumėte su juo daryti?</translation>
     </message>
     <message>
         <location filename="../execfiledialog.cpp" line="46"/>
         <source>This text file &apos;%1&apos; seems to be an executable script.
 What do you want to do with it?</source>
-        <translation>Atrodo, kad šis tekstinis failas &quot;%1&quot; yra vykdomasis scenarijus.
+        <translation>Atrodo, kad šis tekstinis failas „%1“ yra vykdomasis scenarijus.
 Ką norėtumėte su juo daryti?</translation>
     </message>
     <message>
         <location filename="../execfiledialog.cpp" line="51"/>
         <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
-        <translation>Šis failas &quot;%1&quot; yra vykdomasis. Ar norite jį vykdyti?</translation>
+        <translation>Šis failas „%1“ yra vykdomasis. Ar norite jį vykdyti?</translation>
     </message>
 </context>
 <context>
@@ -601,17 +601,17 @@ Ar norite jį pakeisti?</translation>
     <message>
         <location filename="../filedialog.cpp" line="960"/>
         <source>Path &quot;%1&quot; does not exist</source>
-        <translation>Kelio &quot;%1&quot; nėra</translation>
+        <translation>Kelio „%1“ nėra</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="974"/>
         <source>&quot;%1&quot; is not a directory</source>
-        <translation>&quot;%1&quot; nėra katalogas</translation>
+        <translation>„%1“ nėra katalogas</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="980"/>
         <source>&quot;%1&quot; is not a file</source>
-        <translation>&quot;%1&quot; nėra failas</translation>
+        <translation>„%1“ nėra failas</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="1132"/>
@@ -993,17 +993,17 @@ Ar norite vietoj to, juos ištrinti?</translation>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>Error</source>
         <translation>Klaida</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>You should add at least one directory to search.</source>
         <translation>Norėdami ieškoti, turite pasirinkti bent vieną katalogą.</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="159"/>
+        <location filename="../filesearchdialog.cpp" line="164"/>
         <source>Select a folder</source>
         <translation>Pasirinkti aplanką</translation>
     </message>
@@ -1251,7 +1251,7 @@ Ar norite vietoj to, juos ištrinti?</translation>
 <context>
     <name>Fm::MountOperationPasswordDialog</name>
     <message>
-        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
+        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
         <source>&amp;Connect</source>
         <translation>&amp;Prijungti</translation>
     </message>
@@ -1431,7 +1431,7 @@ Pakeista: %2</translation>
     <message>
         <location filename="../core/untrashjob.cpp" line="35"/>
         <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
-        <translation>Nepavyksta iškelti failą &quot;%s&quot; iš šiukšlinės: pradinis kelias nėra žinomas</translation>
+        <translation>Nepavyksta iškelti failo „%s“ iš šiukšlinės: pradinis kelias nėra žinomas</translation>
     </message>
 </context>
 <context>
@@ -1473,11 +1473,16 @@ Pakeista: %2</translation>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
+        <source>Session length is determined by password manager</source>
+        <translation>Seanso trukmę nustato slaptažodžių tvarkytuvė</translation>
+    </message>
+    <message>
+        <location filename="../mount-operation-password.ui" line="140"/>
         <source>Remember password for &amp;this session</source>
         <translation>Prisiminti slaptažodį š&amp;iam seansui</translation>
     </message>
     <message>
-        <location filename="../mount-operation-password.ui" line="147"/>
+        <location filename="../mount-operation-password.ui" line="150"/>
         <source>Remember &amp;forever</source>
         <translation>Prisiminti visam laik&amp;ui</translation>
     </message>
@@ -1485,12 +1490,12 @@ Pakeista: %2</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../utilities.cpp" line="166"/>
+        <location filename="../utilities.cpp" line="170"/>
         <source>Rename File</source>
         <translation>Pervadinti failą</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="167"/>
+        <location filename="../utilities.cpp" line="171"/>
         <source>Please enter a new name:</source>
         <translation>Įrašykite naują pavadinimą:</translation>
     </message>
@@ -1498,43 +1503,43 @@ Pakeista: %2</translation>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="669"/>
         <location filename="../mountoperation.cpp" line="297"/>
-        <location filename="../utilities.cpp" line="150"/>
-        <location filename="../utilities.cpp" line="289"/>
+        <location filename="../utilities.cpp" line="154"/>
+        <location filename="../utilities.cpp" line="317"/>
         <source>Error</source>
         <translation>Klaida</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="226"/>
+        <location filename="../utilities.cpp" line="230"/>
         <source>Create Folder</source>
         <translation>Sukurti aplanką</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="227"/>
+        <location filename="../utilities.cpp" line="231"/>
         <source>Create File</source>
         <translation>Sukurti failą</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="231"/>
+        <location filename="../utilities.cpp" line="235"/>
         <source>Please enter a new file name:</source>
         <translation>Įrašykite naują failo pavadinimą:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="232"/>
+        <location filename="../utilities.cpp" line="236"/>
         <source>New file</source>
-        <translation type="unfinished"></translation>
+        <translation>Naujas failas</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="236"/>
+        <location filename="../utilities.cpp" line="240"/>
         <source>Please enter a new folder name:</source>
         <translation>Įrašykite naują aplanko pavadinimą:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="237"/>
+        <location filename="../utilities.cpp" line="241"/>
         <source>New folder</source>
         <translation>Naujas aplankas</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="242"/>
+        <location filename="../utilities.cpp" line="246"/>
         <source>Enter a name for the new %1:</source>
         <translation>Įrašykite pavadinimą naujam %1:</translation>
     </message>
@@ -1551,17 +1556,17 @@ Pakeista: %2</translation>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="319"/>
         <source>Invalid desktop entry file: &apos;%1&apos;</source>
-        <translation>Neteisingas darbalaukio įrašo failas: &quot;%1&quot;</translation>
+        <translation>Neteisingas darbalaukio įrašo failas: „%1“</translation>
     </message>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="355"/>
         <source>No default application is set to launch &apos;%1&apos;</source>
-        <translation>Nėra nustatyta numatytoji programa, skirta paleisti &quot;%1&quot;</translation>
+        <translation>Nėra nustatyta numatytoji programa, skirta paleisti „%1“</translation>
     </message>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="396"/>
         <source>Cannot set working directory to &apos;%1&apos;: %2</source>
-        <translation>Nepavyksta nustatyti darbinį katalogą į &quot;%1&quot;: %2</translation>
+        <translation>Nepavyksta nustatyti darbinį katalogą į „%1“: %2</translation>
     </message>
     <message>
         <location filename="../placesmodelitem.cpp" line="127"/>
