@@ -58,7 +58,7 @@
     <message>
         <location filename="../app-chooser-dialog.ui" line="109"/>
         <source>Set selected application as default action of this file type</source>
-        <translation>Использовать выбранное приложение как действие по умолчанию для файлов этого типа</translation>
+        <translation>Использовать выбранное приложение по умолчанию для файлов этого типа</translation>
     </message>
 </context>
 <context>
@@ -298,7 +298,7 @@
         <location filename="../file-props.ui" line="545"/>
         <location filename="../file-props.ui" line="694"/>
         <source>Other:</source>
-        <translation>Остальные:</translation>
+        <translation>Прочие:</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="562"/>
@@ -360,7 +360,7 @@
     <message>
         <location filename="../appchooserdialog.cpp" line="268"/>
         <source>Select an application to open &quot;%1&quot; files</source>
-        <translation>Выберите приложение, чтобы открыть &quot;%1&quot; файлов</translation>
+        <translation>Выбор приложения для открытия файлов типа «%1»</translation>
     </message>
 </context>
 <context>
@@ -381,7 +381,7 @@
     <message>
         <location filename="../core/dirlistjob.cpp" line="48"/>
         <source>The specified directory &apos;%1&apos; is not valid</source>
-        <translation>Указанный каталог &apos;%1&apos; некорректен</translation>
+        <translation>Указанный каталог «%1» не является верным</translation>
     </message>
 </context>
 <context>
@@ -459,7 +459,7 @@
         <location filename="../execfiledialog.cpp" line="40"/>
         <source>This file &apos;%1&apos; seems to be a desktop entry.
 What do you want to do with it?</source>
-        <translation>Файл «%1» является .desktop-файлом.
+        <translation>Этот файл «%1» похож на объект рабочего стола.
 Что вы хотите с ним сделать?</translation>
     </message>
     <message>
@@ -523,7 +523,7 @@ What do you want to do with it?</source>
     <message>
         <location filename="../filedialog.cpp" line="158"/>
         <source>Thumbnail View</source>
-        <translation>В виде эскизов</translation>
+        <translation>В виде миниатюр</translation>
     </message>
     <message>
         <location filename="../filedialog.cpp" line="162"/>
@@ -712,7 +712,7 @@ Do you want to replace it?</source>
         <location filename="../filemenu.cpp" line="166"/>
         <location filename="../filemenu.cpp" line="484"/>
         <source>&amp;Move to Trash</source>
-        <translation>&amp;Переместить в корзину</translation>
+        <translation>&amp;Убрать в корзину</translation>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="170"/>
@@ -727,7 +727,7 @@ Do you want to replace it?</source>
     <message>
         <location filename="../filemenu.cpp" line="240"/>
         <source>Unmount</source>
-        <translation>Размонтировать</translation>
+        <translation>Отмонтировать</translation>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="254"/>
@@ -800,18 +800,18 @@ Do you want to delete them instead?</source>
         <location filename="../fileoperation.cpp" line="405"/>
         <source>Do you want to delete the selected file(s)?</source>
         <translation>
-            <numerusform>Вы хотите удалить выбранный файл?</numerusform>
-            <numerusform>Вы хотите удалить выбранные файлы?</numerusform>
-            <numerusform>Вы хотите удалить выбранные файлы?</numerusform>
+            <numerusform>Хотите удалить выделенный файл?</numerusform>
+            <numerusform>Хотите удалить выделенные файлы?</numerusform>
+            <numerusform>Хотите удалить выделенные файлы?</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../fileoperation.cpp" line="423"/>
         <source>Do you want to move the selected file(s) to trash can?</source>
         <translation>
-            <numerusform>Хотите переместить выделенный файл в корзину?</numerusform>
-            <numerusform>Хотите переместить выделенные файлы в корзину?</numerusform>
-            <numerusform>Хотите переместить выделенные файлы в корзину?</numerusform>
+            <numerusform>Хотите убрать выделенный файл в корзину?</numerusform>
+            <numerusform>Хотите убрать выделенные файлы в корзину?</numerusform>
+            <numerusform>Хотите убрать выделенные файлы в корзину?</numerusform>
         </translation>
     </message>
 </context>
@@ -993,17 +993,17 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>You should add at least one directory to search.</source>
         <translation>Вы должны добавить не менее одного каталога для поиска.</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="159"/>
+        <location filename="../filesearchdialog.cpp" line="164"/>
         <source>Select a folder</source>
         <translation>Выберите папку</translation>
     </message>
@@ -1046,7 +1046,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="91"/>
         <source>Invert Selection</source>
-        <translation>Инвертировать выделение</translation>
+        <translation>Обратить выделение</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="98"/>
@@ -1076,7 +1076,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="204"/>
         <source>By Modification Time</source>
-        <translation>По времени изменения</translation>
+        <translation>По дате изменения</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="205"/>
@@ -1086,7 +1086,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="208"/>
         <source>By Deletion Time</source>
-        <translation>По времени удаления</translation>
+        <translation>По дате удаления</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="211"/>
@@ -1111,12 +1111,12 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermenu.cpp" line="220"/>
         <source>Ascending</source>
-        <translation>Возрастающая</translation>
+        <translation>По возрастанию</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="225"/>
         <source>Descending</source>
-        <translation>Убывающая</translation>
+        <translation>По убыванию</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="242"/>
@@ -1251,7 +1251,7 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::MountOperationPasswordDialog</name>
     <message>
-        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
+        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
         <source>&amp;Connect</source>
         <translation>&amp;Соединить</translation>
     </message>
@@ -1261,7 +1261,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../pathbar.cpp" line="134"/>
         <source>&amp;Edit Path</source>
-        <translation>&amp;Редактировать путь</translation>
+        <translation>&amp;Изменить путь</translation>
     </message>
     <message>
         <location filename="../pathbar.cpp" line="137"/>
@@ -1473,11 +1473,16 @@ Modified: %2</source>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
-        <source>Remember password for &amp;this session</source>
-        <translation>Запоминать пароли для &amp;текущей сессии</translation>
+        <source>Session length is determined by password manager</source>
+        <translation>Длительность сеанса определяется менеджером паролей</translation>
     </message>
     <message>
-        <location filename="../mount-operation-password.ui" line="147"/>
+        <location filename="../mount-operation-password.ui" line="140"/>
+        <source>Remember password for &amp;this session</source>
+        <translation>Запоминать пароли для &amp;текущего сеанса</translation>
+    </message>
+    <message>
+        <location filename="../mount-operation-password.ui" line="150"/>
         <source>Remember &amp;forever</source>
         <translation>Запомнить &amp;навсегда</translation>
     </message>
@@ -1488,53 +1493,53 @@ Modified: %2</source>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="669"/>
         <location filename="../mountoperation.cpp" line="297"/>
-        <location filename="../utilities.cpp" line="150"/>
-        <location filename="../utilities.cpp" line="289"/>
+        <location filename="../utilities.cpp" line="154"/>
+        <location filename="../utilities.cpp" line="317"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="166"/>
+        <location filename="../utilities.cpp" line="170"/>
         <source>Rename File</source>
         <translation>Переименовать файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="167"/>
+        <location filename="../utilities.cpp" line="171"/>
         <source>Please enter a new name:</source>
         <translation>Введите новое имя:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="226"/>
+        <location filename="../utilities.cpp" line="230"/>
         <source>Create Folder</source>
         <translation>Создать папку</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="231"/>
+        <location filename="../utilities.cpp" line="235"/>
         <source>Please enter a new file name:</source>
         <translation>Введите имя нового файла:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="232"/>
+        <location filename="../utilities.cpp" line="236"/>
         <source>New file</source>
-        <translation type="unfinished"></translation>
+        <translation>Новый файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="236"/>
+        <location filename="../utilities.cpp" line="240"/>
         <source>Please enter a new folder name:</source>
         <translation>Введите имя новой папки:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="237"/>
+        <location filename="../utilities.cpp" line="241"/>
         <source>New folder</source>
         <translation>Новая папка</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="242"/>
+        <location filename="../utilities.cpp" line="246"/>
         <source>Enter a name for the new %1:</source>
         <translation>Введите имя нового файла (%1):</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="227"/>
+        <location filename="../utilities.cpp" line="231"/>
         <source>Create File</source>
         <translation>Создать файл</translation>
     </message>
